@@ -536,7 +536,7 @@ class WordToken(models.Model):
             nformants = self.getNFormants()
             out = p.get_formants(fetch_buckeye_resource("Speakers/"+path+'.wav'),begin,end,nformants,ceiling)
             dur = float(end)-float(begin)
-            if dur > 0.0:
+            if dur > 0.0 and len(out) > 0:
                 fones = [x['F1(Hz)'] for x in out if x['F1(Hz)'] != '--undefined--' and float(x['time(s)'])/dur> 0.25 and float(x['time(s)'])/dur < 0.75]
                 ftwos = [x['F2(Hz)'] for x in out if x['F2(Hz)'] != '--undefined--' and float(x['time(s)'])/dur> 0.25 and float(x['time(s)'])/dur < 0.75]
                 if len(fones) > 0 and len(ftwos) > 0:
